/***************************************************************************
 *   Copyright (C) 2008 by Rachmaninov,,,   							   *
 *   rachmaninov2@gmail.com												   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef ODTHTML_H
#define ODTHTML_H

#include <QString>
#include <QMap>

// Qt XML

#include <QDomDocument>
#include <QDomElement>
#include <QDomNode>
#include <QXmlStreamWriter>

struct XmlTag {
public:
	QString name;
	QXmlStreamAttributes attrs;
};

struct TextFormat {
public:

	enum {
		Bold = 0x01,
		Italic = 0x02,
		Underline = 0x04
	};

	int style;
};

class OdtHtml {
public:

	OdtHtml(const QString& filename);

	~OdtHtml();

	void convert();

	inline QString& getHtml() {
		return html;
	}	

private:
	QString filename;
	QString html;
	QXmlStreamWriter sw;
	QMap<QString, TextFormat*> mapStyles;

	// Procesa los elementos "office:automatic-styles"
	void processStyles(const QDomElement& rootElement);

	// Procesa cada nodo de estilo
	void processStyleNode(const QDomNode& node);

	// Busca y procesa los elementos office:text
	void processOfficeText(const QDomElement& rootElement);

	// Procesa los hijos del elemento office:text. Estos elementos 
	// componen el contenido del documento.
	void processOfficeTextChild(const QDomNode& node);
};

#endif
